@@ -127,11 +127,10 @@ void MainWindow::closeEvent(QCloseEvent *event)
 {
     if (queryClose() == true) {
         event->accept();
-        return;
     } else {
         event->ignore();
-        return;
     }
+    return;
 }
 
 void MainWindow::setupWidgets()
@@ -153,10 +152,17 @@ void MainWindow::setupWidgets()
     m_hSplitter->addWidget(sidePanel);
 
     // set sizes for script panel
-    m_hScriptSplitter->setSizes(QList<int>() << Settings::hScriptSplitterSizeLeft() << Settings::hScriptSplitterSizeRight() << 80);
+    m_hScriptSplitter->setSizes({
+        Settings::hScriptSplitterSizeLeft(),
+        Settings::hScriptSplitterSizeRight(),
+        80
+    });
 
     // set sizes for vertical splitter
-    m_vSplitter->setSizes(QList<int>() << Settings::vSplitterSizeTop() << Settings::vSplitterSizeBottom());
+    m_vSplitter->setSizes({
+        Settings::vSplitterSizeTop(),
+        Settings::vSplitterSizeBottom()
+    });
 
     // set sizes for side panel
     // the following solves the setting of the panel width if it was closed at previous session
@@ -166,7 +172,11 @@ void MainWindow::setupWidgets()
         // that fixes the wrong saving of hSplitterSizeRight
         panelWidth = 400;
     }
-    m_hSplitter->setSizes(QList<int>() << Settings::hSplitterSizeLeft() << panelWidth);
+
+    m_hSplitter->setSizes({
+        Settings::hSplitterSizeLeft(),
+        panelWidth
+    });
 
     setCentralWidget(m_hSplitter);
 }
@@ -184,14 +194,20 @@ QWidget* MainWindow::setupScriptPanel()
     m_stopScript = new QAction(QIcon::fromTheme("process-stop"), i18nc("@action:intoolbar Script Execution", "Stop"), this);
     m_stopScript->setToolTip(i18nc("@info:tooltip", "Stop script execution."));
     m_stopScript->setEnabled(false);
+    m_openDebugger = new QAction(QIcon::fromTheme("system-run"), i18nc("@action:intoolbar Open Debugger", "Debugger"), this);
+    m_openDebugger->setToolTip(i18nc("@info:tooltip", "Open the Javascript code debugger."));
+    m_openDebugger->setCheckable(true);
     executeCommands->addAction(m_runScript);
     executeCommands->addAction(m_stopScript);
+    executeCommands->addAction(m_openDebugger);
     // add actions to action collection to be able to set shortcuts on them in the ui
     actionCollection()->addAction("_runScript", m_runScript);
     actionCollection()->addAction("_stopScript", m_stopScript);
+    actionCollection()->addAction("_openDebugger", m_openDebugger);
 
     connect(m_runScript, &QAction::triggered, this, &MainWindow::executeScript);
     connect(m_stopScript, &QAction::triggered, this, &MainWindow::stopScript);
+    connect(m_openDebugger, &QAction::triggered, this, &MainWindow::checkDebugger);
 
     m_hScriptSplitter->addWidget(m_codeEditorWidget);
     m_hScriptSplitter->addWidget(m_outputWidget);
@@ -206,18 +222,13 @@ QWidget* MainWindow::setupScriptPanel()
 
 QWidget* MainWindow::setupSidePanel()
 {
-    QWidget *panel = new QWidget(this);
-    panel->setLayout(new QVBoxLayout);
-    panel->setVisible(false);
-
     // add sidebar
-    SidedockWidget* sideDock = new SidedockWidget(panel);
+    SidedockWidget* sideDock = new SidedockWidget(this);
     addToolBar(Qt::RightToolBarArea, sideDock->toolbar());
-    panel->layout()->addWidget(sideDock);
 
     // add widgets to dock
     // document property widgets
-    DocumentTypesWidget *documentTypesWidget = new DocumentTypesWidget(panel);
+    DocumentTypesWidget *documentTypesWidget = new DocumentTypesWidget(this);
     connect(this, &MainWindow::graphDocumentChanged, documentTypesWidget, &DocumentTypesWidget::setDocument);
     sideDock->addDock(documentTypesWidget, i18n("Element Types"), QIcon::fromTheme("document-properties"));
     if (m_currentProject && m_currentProject->activeGraphDocument()) {
@@ -225,14 +236,14 @@ QWidget* MainWindow::setupSidePanel()
     }
 
     // Project Journal
-    m_journalWidget = new JournalEditorWidget(panel);
+    m_journalWidget = new JournalEditorWidget(this);
     sideDock->addDock(m_journalWidget, i18nc("@title", "Journal"), QIcon::fromTheme("story-editor"));
 
     // Rocs scripting API documentation
-    ScriptApiWidget* apiDoc = new ScriptApiWidget(panel);
+    ScriptApiWidget* apiDoc = new ScriptApiWidget(this);
     sideDock->addDock(apiDoc, i18nc("@title", "Scripting API"), QIcon::fromTheme("documentation"));
 
-    return panel;
+    return sideDock;
 }
 
 void MainWindow::setProject(Project *project)
@@ -325,7 +336,7 @@ void MainWindow::setupToolsPluginsAction()
     QList<QAction*> actions;
     int count = 0;
     for (auto plugin : availablePlugins) {
-        QAction *action = new QAction(plugin->displayName(), this);
+        auto *action = new QAction(plugin->displayName(), this);
         action->setData(count++);
         connect(action, &QAction::triggered,
             this, &MainWindow::showEditorPluginDialog);
@@ -379,10 +390,11 @@ void MainWindow::saveProject()
     if (m_currentProject->projectUrl().isEmpty()) {
         saveProjectAs();
         return;
-    } else {
-        m_currentProject->projectSave();
-        m_recentProjects->addUrl(m_currentProject->projectUrl());
     }
+
+    m_currentProject->projectSave();
+    m_recentProjects->addUrl(m_currentProject->projectUrl());
+
     updateCaption();
 }
 
@@ -423,18 +435,16 @@ void MainWindow::openProject(const QUrl &fileName)
 
     QString startDirectory = Settings::lastOpenedDirectory();
     QUrl file = fileName;
-    if (file.isEmpty()){
+    if (file.isEmpty()) {
     // show open dialog
          file = QUrl::fromLocalFile(QFileDialog::getOpenFileName(this,
                     i18nc("@title:window", "Open Project Files"),
                     startDirectory,
                     i18n("Rocs projects (*.rocs)")));
-
-        if (file.isEmpty()) {
-            return;
-        }
     }
-
+    if (file.isEmpty()) {
+        return;
+    }
     Project *project = new Project(file, m_graphEditor);
     setProject(project);
     m_recentProjects->addUrl(file);
@@ -448,6 +458,7 @@ void MainWindow::updateCaption()
     if (!m_currentProject) {
         return;
     }
+
     QString modified;
     if (m_currentProject->isModified()) {
         modified = '*';
@@ -511,20 +522,22 @@ bool MainWindow::queryClose()
     if (!m_currentProject) {
         return true;
     }
-    if (m_currentProject->isModified()) {
-        const int btnCode = KMessageBox::warningYesNoCancel(this, i18nc(
-                                "@info",
-                                "Changes on your project are unsaved. Do you want to save your changes?"));
-        if (btnCode == KMessageBox::Yes) {
-            saveProject();
-            return true;
-        }
-        if (btnCode == KMessageBox::No) {
-            return true;
-        }
-        return false; // do not close
+    if (!m_currentProject->isModified()) {
+        return true;
     }
-    return true; // save to close project: no changes
+    const int btnCode = KMessageBox::warningYesNoCancel(this, i18nc(
+                            "@info",
+                            "Changes on your project are unsaved. Do you want to save your changes?"));
+
+    if (btnCode == KMessageBox::Cancel) {
+        return false;
+    }
+
+    if (btnCode == KMessageBox::Yes) {
+        saveProject();
+    }
+
+    return true;
 }
 
 void MainWindow::quit()
@@ -570,6 +583,11 @@ void MainWindow::executeScript()
     }
     QString script = m_codeEditorWidget->activeDocument()->text();
     enableStopAction();
+
+    if (m_openDebugger->isChecked()) {
+        m_kernel->triggerInterruptAction();
+    }
+
     m_kernel->execute(m_currentProject->activeGraphDocument(), script);
 }
 
@@ -579,6 +597,15 @@ void MainWindow::stopScript()
     disableStopAction();
 }
 
+void MainWindow::checkDebugger()
+{
+    if (m_openDebugger->isChecked()) {
+        m_kernel->attachDebugger();
+    } else {
+        m_kernel->detachDebugger();
+    }
+}
+
 void MainWindow::enableStopAction()
 {
     m_stopScript->setEnabled(true);
